#include <rtx51.h>
#include <reg552.h>
#include <stdio.h>
#include <stdlib.h>
#include <dsw.h>

#define	K	(1.0/256.0)

#ifndef READ
	#define	READ 1
#endif
#ifndef WRITE
	#define	WRITE 0
#endif

#define	EEPROM_WAIT	1

extern void Delay(unsigned char);

extern void I2C_Start(void);
extern void I2C_Stop(void);
extern unsigned char I2C_Read(unsigned char);
extern unsigned char I2C_SendByte(unsigned char);
extern unsigned char I2C_SendAddr(unsigned char);
extern void Write_TH_Register(unsigned char, unsigned int);
extern void Write_TL_Register(unsigned char, unsigned int);
extern unsigned int Read_TH(unsigned char);
extern unsigned int Read_TL(unsigned char);

#ifdef DS1631												//DS1631 je maximlne 12bitov teplomer
 #define START_CONVERT   	0x51			//DS1631 I2C_START_CONVERT = 0x51, DS1624 I2C_START_CONVERT = 0xEE
#endif

#ifdef DS1624												//DS1624 je maximlne 13bitov teplomer
 #define START_CONVERT   	0xEE			//DS1631 I2C_START_CONVERT = 0x51, DS1624 I2C_START_CONVERT = 0xEE
 #define ACCESS_MEMORY   	0x17			//DS1624
#endif

#define STOP_CONVERT     	0x22
#define	ACCESS_TH					0xA1
#define	ACCESS_TL					0xA2
#define READ_TEMPERATURE 	0xAA
#define DS1631_COMMAND		0xAC
#define DS1624_COMMAND		0xAC
#define COMMAND_DONE			0x80
#define COMMAND_1SHOT			0x01
#define POR								0x54
#define READ_COUNTER			0xA8			//DS1621
#define READ_SLOPE				0xA9			//DS1621

#define AddrDS1631A	0x90							//Adresa pre DS1621,DS1624,DS1631 - tzv. CONTROL_BYTE
#define AddrDS1624A	0x90							//Adresa pre DS1621,DS1624,DS1631 - tzv. CONTROL_BYTE
#define AddrAT24c32	0xA0							//Adresa pre AT24C08 az AT24C64 - tzv. CONTROL_BYTE
#define	AddrDS1807A	0x50							//Adresa pre DS1807A - tzv. CONTROL_BYTE

unsigned char Get_Config(unsigned char Adresa)
{
 register unsigned char LSB;
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(DS1631_COMMAND);
 I2C_SendAddr(Adresa+READ); 
 LSB=I2C_Read(1);
 I2C_Stop();
 return(LSB);
}

#ifdef DS1631

void Write_Config(unsigned char Adresa, unsigned char Data)
{
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(DS1631_COMMAND);
 I2C_SendByte(Data);
 os_wait(K_TMO,EEPROM_WAIT,NULL);		//Cakam 10ms cez RTX51 Full
 I2C_Stop();
}

void Config_DS16xx(unsigned char Adresa, unsigned char Bits)
{
 register unsigned char Config;
 register unsigned int Temp;
 Temp=Read_TH(AddrDS1631A);
 Temp=Read_TL(AddrDS1631A); 
 Write_TH_Register(AddrDS1631A,0xabcd);
 Write_TL_Register(AddrDS1631A,0x1234);
 Config=Get_Config(Adresa);
 Config&=~(0x08+0x04);
 switch(Bits)
  {
	 case	9		:	break;
	 case	10	:	Config|=0x04;	break;
	 case	11	:	Config|=0x08;	break;
	 default	:	Config|=0x0c;	break;	//Ak je zadana zla hodnota alebo 12 tak nastavim 12 bitov
	}
 Write_Config(Adresa,Config);				//Nastavim 12 bitovy prevod
}

#endif

unsigned int Get_Int_Temp(unsigned char Adresa)
{
 register unsigned char MSB,LSB;
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(START_CONVERT);
 I2C_Stop();
//---------------------------------------------------
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(STOP_CONVERT);
 I2C_Stop();
//---------------------------------------------------
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(READ_TEMPERATURE);
 I2C_SendAddr(Adresa+READ);
 MSB=I2C_Read(1);			//Vyzaduje sa zo SLAVE-a potvrdenie ACK=0!!!
 LSB=I2C_Read(0);			//Vyzaduje sa z MASTER-a potvrdenie ACK=1!!!
 I2C_Stop();
//**************************************************
 if(MSB>=0x80) return((MSB*256+LSB)-65536); else return(MSB*256+LSB);														//Je to OK !!!
//**************************************************	
}

float Get_Float_Temp(unsigned char Adresa)
{
 register unsigned char MSB,LSB;
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(START_CONVERT);
 I2C_Stop();
//---------------------------------------------------
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(STOP_CONVERT);
 I2C_Stop();
//---------------------------------------------------
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(READ_TEMPERATURE);
 I2C_SendAddr(Adresa+READ);
 MSB=I2C_Read(1);			//Vyzaduje sa zo SLAVE-a potvrdenie ACK=0!!!
 LSB=I2C_Read(0);			//Vyzaduje sa z MASTER-a potvrdenie ACK=1!!!
 I2C_Stop();					//MSB=0x19; LSB=0x10;	//25.062C
//**************************************************
 if(MSB>=0x80) return((float)(MSB*256+LSB)-65536); else return((float)(MSB*256+LSB)*K);		//Je to OK !!!
//**************************************************	}
}

#ifdef DS1631

void Write_TH_Register(unsigned char Adresa, unsigned int THReg)
{
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(ACCESS_TH);						// !!!!!!!!!!!!!!!!!!!!!
 I2C_SendByte(high(THReg));
 I2C_SendByte(low(THReg));
 I2C_Stop();
 os_wait(K_TMO,EEPROM_WAIT,NULL);		//Cakam 10ms cez RTX51 Full
}

void Write_TL_Register(unsigned char Adresa, unsigned int TLReg)
{
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(ACCESS_TL);						// !!!!!!!!!!!!!!!!!!!!!
 I2C_SendByte(high(TLReg));
 I2C_SendByte(low(TLReg));
 I2C_Stop();
 os_wait(K_TMO,EEPROM_WAIT,NULL);		//Cakam 10ms cez RTX51 Full
}

unsigned int Read_TH(unsigned char Adresa)
{
 register unsigned char MSB,LSB; 
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(ACCESS_TH);
 I2C_SendAddr(Adresa+READ);
 MSB=I2C_Read(1);
 LSB=I2C_Read(0);
 I2C_Stop();
 return(MSB*0x100+LSB);
}

unsigned int Read_TL(unsigned char Adresa)
{
 register unsigned char MSB,LSB;
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(ACCESS_TL);
 I2C_SendAddr(Adresa+READ);
 MSB=I2C_Read(1);
 LSB=I2C_Read(0);
 I2C_Stop();
 return(MSB*0x100+LSB);
}

#endif

#ifdef DS1624

void Write_Eprom_DS1624(unsigned char Adresa, unsigned char EEprom_Addr, unsigned char Data)	//Funguje zapis a aj citanie do DS1624
{
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(ACCESS_MEMORY);
 I2C_SendByte(EEprom_Addr);
 I2C_SendByte(Data);
 I2C_Stop();
 os_wait(K_TMO,EEPROM_WAIT,NULL);		//Cakam 10ms cez RTX51 Full
}

unsigned char Read_Eprom_DS1624(unsigned char Adresa, unsigned char EEprom_Addr)	//Funguje zapis a aj citanie do DS1624
{
 register unsigned char LSB;
 I2C_SendAddr(Adresa+WRITE);
 I2C_SendByte(ACCESS_MEMORY);
 I2C_SendByte(EEprom_Addr);
 I2C_SendAddr(Adresa+READ); 
 LSB=I2C_Read(0);
 I2C_Stop();
 return(LSB);
}

void Write_Block_E2prom_DS1624(unsigned char Adresa, unsigned char EEprom_Addr, unsigned char Dlzka, unsigned char *Buffer)
{
 register unsigned char i;
 for(i=0x00; i<Dlzka; i++)
  {
	 Write_Eprom_DS1624(Adresa,EEprom_Addr+i,Buffer[i]);	//Funguje zapis a aj citanie do DS1624
	}
}

void Read_Block_E2prom_DS1624(unsigned char Adresa, unsigned char EEprom_Addr, unsigned char Dlzka, unsigned char *Buffer)
{
 register unsigned char i;
 for(i=0x00; i<Dlzka; i++)
  {
	 Buffer[i]=Read_Eprom_DS1624(Adresa,EEprom_Addr+i);		//Funguje zapis a aj citanie do DS1624
	} 
}

#endif