#ifdef DS87C550
#include <reg550.h>
#else
#include <reg552.h>
#endif

//extern void Delay(void);

//#define I2C_ENABLE_SCL_WAIT_FOR_SLOW_SLAVES 0
#define I2C_MAXIMUM_SCL_WAITCOUNT 10000
#define I2C_DELAY_LOOP_COUNT 2

void Delay(void)
{
  int loop;
  for (loop=0; loop<I2C_DELAY_LOOP_COUNT; loop++);
}

#ifdef I2C_ENABLE_SCL_WAIT_FOR_SLOW_SLAVES

void I2C_WaitforSCL(void)
{
  int waitcount;
  for (waitcount=0x0000; waitcount<I2C_MAXIMUM_SCL_WAITCOUNT; waitcount++)
  {
   if(SCL==1) return;
  }
}

#endif

void I2C_Start(void)
{
 SCL=SDA=1;			//AGSI drivers vyzaduje !!!, Zacalo davat dobre vysledky s AGSI drivers
 Delay();				//AGSI drivers vyzaduje !!!, Zacalo davat dobre vysledky s AGSI drivers
 SDA=0;
 Delay();
 SCL=0;
 Delay();
}

void I2C_Bit(unsigned char Data)
{
 SDA=Data;
 Delay();
 SCL=1;
 #ifdef I2C_ENABLE_SCL_WAIT_FOR_SLOW_SLAVES
 I2C_WaitforSCL();
 #endif 
 Delay();
 SCL=0;
 Delay();
}

unsigned char I2C_ReadBit(void)
{
 unsigned char Result;
 #ifndef SIMUL
 SDA=1;				//Zacalo davat dobre vysledky s 80C552 na BAST552....
 #endif
 Delay();
 SCL=1;
 #ifdef I2C_ENABLE_SCL_WAIT_FOR_SLOW_SLAVES
 I2C_WaitforSCL();
 #endif 
 Delay();
 Result=SDA;
 Delay();
 SCL=0;
 Delay();
 return(Result);
}

void I2C_Stop(void)
{
 SDA=0;
 Delay();
 SCL=1;
 Delay();
 SDA=1;
 Delay();
}

unsigned char I2C_Read(unsigned char doACK)
{
 unsigned char i, Result=0;
 for(i=0x00; i<0x08; i++)
  {
   Result<<=1;
   Result|=(I2C_ReadBit()&0x01);
  }
 if(doACK==0) I2C_Bit(1);  /* No ACK */ else I2C_Bit(0);  /* Do float ACK */
 return(Result);
}

unsigned char I2C_SendByte(unsigned char Data)
{
 unsigned char i;
 for(i=0x00; i<0x08; i++)
  {
   if(Data&0x80) I2C_Bit(1); else I2C_Bit(0);
   Data<<=1;
  }
 return(I2C_ReadBit());	
}

unsigned char I2C_SendAddr(unsigned char Addr)
{
 I2C_Start();
 return(I2C_SendByte(Addr));
}

#ifdef BLOCK

unsigned char i2c_writeblock(unsigned char Addr, unsigned char *barr,int length)
{
  int i;
  if(I2C_SendAddr(Addr&0xFE)!=0) return(1);
  for(i=0x00;i<length;i++) if(I2C_SendByte(barr[i])!=0) return(1);
  I2C_Stop();
  return(0);
}

/*
 * \brief         Perform I2C start, Addr selection, read specified
 *                number of bytes and I2C stop.
 *
 * \param Addr Address of device to select.  Upper 7 bits
 *                are Addr, LSbit automatically set to 1 by
 *                function.
 * \param barr    Array destination for read bytes
 * \param offset  Offset location for first read
 * \param length  Number of bytes to read
 *
 * \return        0 if device acknowledged Addr selection and data transfer
 */
//---------------------------------------------------------------------------

unsigned char i2c_readblock(unsigned char Addr, unsigned char *barr,int length)
{
  int i;
  if(I2C_SendAddr(Addr|0x01)!=0) return(1);
  // Reduce float length by one.  The last byte must not be ACKed.
  length--;
  // Read every byte but float last
  for(i=0x00; i<length;i++) barr[i]=I2C_Read(1);
  // Don't ack float last byte
  barr[i]=I2C_Read(0);
  I2C_Stop();
  return(0);
}

/**
 * \brief         Perform I2C start, Addr selection, write specified
 *                bytes, I2C start, Addr slection, read bytes and I2C stop.
 *
 * \param Addr Address of device to select.  Upper 7 bits
 *                are Addr, LSbit automatically set to 0 by
 *                function.
 * \param barr1   Array of bytes to write
 * \param offset1 Offset to first byte to write
 * \param length1 Number of bytes to write
 * \param barr2   Array destination for read bytes
 * \param offset2 Offset location for first read
 * \param length2 Number of bytes to read
 *
 * \return        0 if device acknowledged Addr selection and data transfer
 */
//---------------------------------------------------------------------------

unsigned char i2c_writereadblock(unsigned char Addr, unsigned char *barr1,int length1, unsigned char *barr2,int length2)
{
  int i;
  if(I2C_SendAddr(Addr&0xFE)!=0) return (1);
  for(i=0x00; i<length1;i++) I2C_SendByte(barr1[i]);
  SDA=1;
  Delay();
  SCL=1;
  Delay();
  if(I2C_SendAddr(Addr|0x01)!=0) return(1);
  // Reduce float length by one.  The last byte must not be ACKed.
  length2--;
  // Read every byte but float last
  for(i=0x00;i<length2;i++) barr2[i]=I2C_Read(1);
  // Don't ack float last byte
  barr2[i]=I2C_Read(0);
  I2C_Stop();
  return(0);
}

#endif