#include <reg552.h>
#include <stdio.h>				/* standard I/O .h-file               */
#include <ctype.h>				/* character functions                */
#include <string.h>				/* string and memory functions        */
#include <stdlib.h>
#include <rtx51.h>
#include <pidreg.h>
#include <dsw.h>

#include <konstanty.inc>

#define Port		P1
#define	LCD			0xFF	//Inicializacia portu ....
#ifdef x12
 #define	Dlzka		20	//pre 18.432MHz AT89LP4052, bola 255
#else
 #define	Dlzka		5		//pre 18.432MHz, bola 60
#endif

sbit	LCD_EN	=	P4^1;
sbit	LCD_RS	=	P4^2;
sbit	LCD_RW	=	P4^3;

extern void Delay(unsigned char);

sbit LCD7	=	P4^7;
sbit LCD6	=	P4^6;
sbit LCD5	=	P4^5;
sbit LCD4	=	P4^4;

code unsigned char Line[4]={Riadok1,Riadok2,Riadok3,Riadok4};

void LCD_Clock(void)
{
 LCD_EN=1;
 #ifdef x12					//Cakaj cca. 50us
  Delay(Dlzka);			
  Delay(Dlzka);
  Delay(Dlzka);
 #else							//Cakaj cca. 50us
  Delay(Dlzka);
 #endif
 LCD_EN=0;
}

void LCD_Send(unsigned char Data)
{
 LCD7=(Data&0x80)?1:0;		//Posielam MSB
 LCD6=(Data&0x40)?1:0;
 LCD5=(Data&0x20)?1:0;
 LCD4=(Data&0x10)?1:0;
 LCD_Clock();
 LCD7=(Data&0x08)?1:0;		//Posielam LSB
 LCD6=(Data&0x04)?1:0;
 LCD5=(Data&0x02)?1:0;
 LCD4=(Data&0x01)?1:0;
 LCD_Clock();
}

void LCD_Data(unsigned char Data)
{
 LCD_RS=1;  						//Pretoze odosielam data !!!
 LCD_EN=0;
 LCD_RW=0;
 LCD_Send(Data);
}

void LCD_Cmd(unsigned char Data)
{
 LCD_RS=0;							//Pretoze odosielam prikaz !!!
 LCD_EN=0;
 LCD_RW=0;
 LCD_Send(Data); 
}

void LCD_ClrScr(void)
{
 LCD_Cmd(0x01);
 os_wait(K_TMO,20,NULL);
}

void LCD_Goto(unsigned char i)
{
 LCD_Cmd(0x80+Line[i]);
 Delay(Dlzka);
}

void LCD_Home(void)
{
 LCD_Cmd(0x02);
 os_wait(K_TMO,20,NULL);
}

void LCD_Init(void)
{
 LCD_RS=0;
 LCD_RW=0;									//Je to len balast pre LCD Display
 LCD_EN=0;
 #ifdef x12
//  Port&=0xF0;						//Nemusi tu byt 0 pre 4 bitovy rezim ...
  P1M0=P3M0=P1M1=P3M1=0x00;
 #endif
 //Port=LCD;
 os_wait(K_TMO,20,NULL);	//Cakaj cca. 20ms, povodny a fungujuci kod ...
 LCD_Cmd(0x33);
 os_wait(K_TMO,10,NULL);
 LCD_Cmd(0x32);
 os_wait(K_TMO,10,NULL); 
 LCD_Cmd(0x20+0x08);
 LCD_Cmd(0x10+0x00);
 LCD_Cmd(0x08+0x04);	//LCD_Cmd(0x08+0x04+1); Cursor Blink Function
 LCD_Cmd(0x04+0x02);
 LCD_ClrScr();
 LCD_Goto(Line1);
 LCD_Home();
}

void LCD_Write_String(char *String)
{
 unsigned char i;
 for(i=0x00; i<LCD_Size; i++)
  {
	 switch(String[i])
		{
		 case	'\n'	:
		 case	'\r'	: 
		 case	'\0'	:	String[i]=' '; break;
		}
		LCD_Data(String[i]);
	}
 //memset(String,' ',LCD_Size);	
}

void LCD_Line(lcd_screen *p, unsigned char i)
{
 LCD_Goto(i);
 LCD_Write_String(p->lcd_line[i]);
}
/*
void LCD_Line(lcd_screen *p, unsigned char i)
{
 LCD_Cmd(0x80+Line[i]);
 Delay(Dlzka);
 LCD_Write_String(p->lcd_line[i]);
}
*/
void LCD_Screen(lcd_screen *p)
{
 unsigned char i;
 for(i=Line1; i<=Line4; i++) LCD_Line(p,i);
}

//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
/*
typedef struct _lcd_screen
{
 unsigned char lcd_line[4][LCD_Size+2];
}
lcd_screen;

xdata lcd_screen New_Screen,Old_Screen;

unsigned char LCD_Screen(lcd_screen *new_scr, lcd_screen *old_scr)															//Otestovana varianta, zisti ktory riadok sa zmenil ...
{
 unsigned char i,Result=0;
 for(i=0; i<4; i++)
  {
	 switch(memcmp(new_scr->lcd_line[i],old_scr->lcd_line[i],sizeof(new_scr->lcd_line[i])))				//Ak su oba retazce rovnake potom Result=0, inac Result<>0
	  {
			case	0	:	break;
			default	:	memcpy(old_scr->lcd_line[i],new_scr->lcd_line[i],sizeof(new_scr->lcd_line[i]));	//Old=New zapamatam si stare hodnoty ....
								switch(i)
								{
								 case	0		:	Result+=1; break;
								 case	1		:	Result+=2; break;
								 case	2		:	Result+=4; break;
								 case	3		:	Result+=8; break;
								}
								break;
		}
	}
 return(Result);
}

unsigned char LCD_Screen(lcd_screen *new_scr, lcd_screen *old_scr)
{
 unsigned char Result;
 Result=memcmp(new_scr,old_scr,sizeof(new_scr));
 //if(Result!=0) memcpy(old_scr,new_scr,sizeof(new_scr));
 return(Result);
}

unsigned char Vysledok;

void TST(void)
{
 strcpy(New_Screen.lcd_line[0],"0\r\n");
 strcpy(New_Screen.lcd_line[1],"1\r\n");
 strcpy(New_Screen.lcd_line[2],"2\r\n");
 strcpy(New_Screen.lcd_line[3],"3\r\n");
 Vysledok=LCD_Screen(&New_Screen,&Old_Screen);
}
*/
//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!