#ifndef __PIDREG_H__
#define __PIDREG_H__

#define GMA_HLIM (255.0) 	// PID controller upper limit [%]
#define GMA_LLIM (0.0) 		// PID controller lower limit [%]

enum {NOR=0, PID=1, ALE=2, TAK=3, PSD=4, DSP=5};
enum {P_Type=1, PI_Type=2, PD_Type=3, PID_Type=4};
enum {ZIE=1, COH=2, ITA=3};

#define	Numbers_Regulators	4					//Pocet pouzitych regulatorov od REGK0 do REGV1 .... viac nie !!!

#define RegKSrvMin			0
#define RegKSrvZdvih		12
#define RegKSrvPosun		15
#define	RegKSrvMax			(RegKSrvZdvih*RegKSrvPosun)																									//Natocenie o 180 za 180 sekund, Zdvih=12mm, Posun=15s/mm = 12*15=180s
#define RegKSrvHyster		2
#define RegVSrvMin			0
#define RegVSrvZdvih		12
#define RegVSrvPosun		3
#define	RegVSrvMax			(RegVSrvZdvih*RegVSrvPosun)																									//Natocenie o 180 za 36 sekund, Zdvih=12mm, Posun=3s/mm = 12*3=36s
#define RegVSrvHyster		2

//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#define	Tu					115.0										// Tu - cas prietahu tzv. Death-Time vid. J. BALTE: AUTOMATICK RZEN str. 234
#define	Tn					14691.0									// Tn - cas nabehu
#define	dy					180.0										// Rozsah servoventilu, alebo maxima statickej sustavy ...
#define	du					(float)RegKSrvZdvih			// Max. hodnota zdvihu servoventilu
#define	ks					(dy/du)									// ks - koeficient prenosu (zosilnenie), alebo statick zosilnenie
#define	a0					(1.0/ks)								// a0 - Cinitel samoregulcie
#define	kr_p				(1.25*(Tn/Tu)*(1.0/ks))	// Kr* - proporcionalna konstanta s rozmerom
#define	Tik					(2.0*Tu)								// Tik - integracna konstanta
#define Tdk					(0.5*Tu)								// Tdk - derivacna konstanta
#define	ddyr				(du/kr_p)								// ddyr - hodnota na max. zdvih
#define	pp_p				((ddyr/dy)*100.0)				// pp_k - psmo proporcionality
#define	Kr_k				((1.0/pp_p)*100.0)			// Kr_k - proporcionalna konstanta bez rozmeru ktoru potrebujem ...
//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

#define	AntiWin			0									//AntiWinDup = 10 dava OK vysledky ... Beznarazove prepinanie, obmedzuje +-5% strmost narastu ???, alebo poklesu vystupnej hodnoty regulatora ...
#define RKkc				Kr_k							//156.2
#define RKti				Tik								//230.0
#define RKtd				Tdk								//57.5
#define	RKts				0.250							//ts=vzorkovanie regulatora, v tasku nesmie prekrocit 254ms t.j. 0.254 !!!
#define	RKk_lpf			0.1*RKtd					//filtracia D-zlozky
#define RVkc				Kr_k
#define RVti				Tik
#define RVtd				Tdk
#define	RVts				0.250							//ts=vzorkovanie regulatora, v tasku nesmie prekrocit 254ms t.j. 0.254 !!!
#define	RVk_lpf			0.1*RVtd					//filtracia D-zlozky

#define alfak (RKts+2.0*RKk_lpf)
#define alfav (RVts+2.0*RVk_lpf)

typedef union _Result
{
 //unsigned char id[2];															//id[tasknum=0] obsahuje cislo zdrojoveho tasku, id[ch=1] obsahuje cislo ziadaneho kanala pre AD prevodnik
 unsigned char addr[2];															//addr[0] hodnotu ktoru ma odovzdat a addr[1] obsahuje adresu I2C zariadenia... ,ACTION=0, DEVICE=1
 unsigned int taskid;																//ID posielam zdrojovemu tasku ako celu hodnotu z AD prevodniku na vykonanie prevodu pre pozadovany task a kanal ...
 unsigned int value;																//Odovzdavam hodnotu z prevodnika tasku ktory bol uvedeny v ...
} 
Result;

typedef struct _Frame
{
 unsigned char DstTask,SrcTask;
 unsigned int Value;
 float FloatValue;
 unsigned char Action;
 unsigned char Channel;
 unsigned char DstAddr,SrcAddr;
}
Frame;

typedef struct _pid_params
{
	float kc; 		// Controller gain for P from Dialog Box
	float ti; 		// Time-constant for I action from Dialog Box
	float td; 		// Time-constant for D action from Dialog Box
	float ts; 		// Sample time [sec.] from Dialog Box
	float k_lpf; 	// Time constant [sec.] for LPF filter
	float k0; 		// k0 value for PID controller
	float k1; 		// k1 value for PID controller
	float k2; 		// k2 value for PID controller
	float k3; 		// k3 value for PID controller
	float lpf1;		// value for LPF filter
	float lpf2; 	// value for LPF filter
	unsigned char os_wait_ts_ticks; // ticks for timer
	int pid_model;// PID Controller type [0..3]
	float pp; 		// debug
	float pi; 		// debug
	float pd; 		// debug
	float Temp;		// Temporary value for WinDup
	float	Soll;		// Ziadana hodnota teploty ...
	int SetPosition,ActualPosition,dPosition;
	int Servo_Min,Servo_Max,Pump,Hysterezia;
	int Tkomfort,Tutlm,deltaT,Tmin,Tmax,Tlimit;
	int AntiWinDup;	//Beznarazove prepinanie, obmedzuje +-10% strmost narastu, alebo poklesu vystupnej hodnoty regulatora ...
	char Ekviterm;	//Ekvitermicka - vykurovacia krivka ...
	//Result Message;
	//Frame Data_Frame;
}
pid_params; // struct pid_params

typedef struct	_var_params
{
	float ek_1; 	// e[k-1] = SP[k-1] - PV[k-1] = Tset_hlt[k-1] - Thlt[k-1]
	float ek_2; 	// e[k-2] = SP[k-2] - PV[k-2] = Tset_hlt[k-2] - Thlt[k-2]
	float xk_1; 	// PV[k-1] = Thlt[k-1]
	float xk_2; 	// PV[k-2] = Thlt[k-1]
	float yk_1; 	// y[k-1] = Gamma[k-1]
	float yk_2; 	// y[k-2] = Gamma[k-1]
	float lpf_1;	// lpf[k-1] = LPF output[k-1]
	float lpf_2;	// lpf[k-2] = LPF output[k-2]
}
var_params;	// struct var_params

typedef struct _pid_Ekviterm
{
 float a,b;
 float t[100+1];
}
pid_Ekviterm;

#endif